pub fn assemble_contract_deck(cx: &mut Cx) -> Result<ContractDeck>Expand description
Assembles a source-free contract deck from the live registry and browse Cards.
pub fn assemble_contract_deck(cx: &mut Cx) -> Result<ContractDeck>Assembles a source-free contract deck from the live registry and browse Cards.