query_contract_deck

Function query_contract_deck 

pub fn query_contract_deck(
    cx: &mut Cx,
    cache: &mut ContractDeckCache,
    query: &ShapeQuery,
) -> Result<Vec<RankedContractCard>>
Query a cached FORGE contract deck by argument and result Shape.

Argument matching is contravariant: a candidate callable must accept at least the requested arguments. Result matching is covariant: a candidate callable must return a shape contained by the requested result shape.