pub fn run_author_bench(
cx: &mut Cx,
cases: &[AuthorCase],
arms: &[AuthorArm],
) -> Result<AuthorBenchReport>Expand description
Runs the offline authoring benchmark with deterministic fakes only.
pub fn run_author_bench(
cx: &mut Cx,
cases: &[AuthorCase],
arms: &[AuthorArm],
) -> Result<AuthorBenchReport>Runs the offline authoring benchmark with deterministic fakes only.