pub fn store_packet_artifact(
cx: &mut Cx,
packet: &BridgePacket,
) -> Result<ContentId>Expand description
Stores a BRIDGE packet artifact in the context datum store and returns its canonical packet content id.
pub fn store_packet_artifact(
cx: &mut Cx,
packet: &BridgePacket,
) -> Result<ContentId>Stores a BRIDGE packet artifact in the context datum store and returns its canonical packet content id.