pub struct VerifyProbe {
pub args: Expr,
pub oracle: ProbeOracle,
pub verifier_ids: Vec<Symbol>,
}Expand description
Concrete case that proves a compiled intent against required verifiers.
Fields
args: ExprConcrete arguments for the known case.
oracle: ProbeOracleExpected answer or evidence reference for the known case.
verifier_ids: Vec<Symbol>Verifier ids that must pass on this probe.
Implementations
Sourceimpl VerifyProbe
impl VerifyProbe
Sourcepub fn content_id(&self) -> Result<ContentId>
pub fn content_id(&self) -> Result<ContentId>
Returns the content id of this probe record.