pub struct RouteTarget<'a> {
pub id: String,
pub fabric: &'a dyn EvalFabric,
pub required_capabilities: Vec<Symbol>,
pub card: Option<String>,
}Expand description
One eval target in a cost-ordered route ladder.
Fields
id: StringStable route id recorded in provenance and attempt reports.
fabric: &'a dyn EvalFabricEval fabric used for this target.
required_capabilities: Vec<Symbol>Capabilities this concrete target requires in addition to the packet request capabilities.
card: Option<String>Optional model or placement card recorded when this target answers.
Implementations
Sourceimpl<'a> RouteTarget<'a>
impl<'a> RouteTarget<'a>